(***********************************************************************)
(*                                                                     *)
(*                              Ref-indic                              *)
(*                                                                     *)
(*                        Refinement indicators                        *)
(*                                                                     *)
(*               EPI Pomdapi, INRIA Paris - Rocquencourt               *)
(*                                                                     *)
(*  Copyright (c) 2013-2014 INRIA.                                     *)
(*  Institut National de Recherche en Informatique et en Automatique.  *)
(*  All rights reserved. This file is distributed only by permission.  *)
(*                                                                     *)
(*  Hend Ben Ameur <hbenameur@yahoo.ca>                                *)
(*  Francois Clement <Francois.Clement@inria.fr>                       *)
(*  Pierre Weis <Pierre.Weis@inria.fr>                                 *)
(*                                                                     *)
(***********************************************************************)

(* $Id: state_types_spec.mli,v 1.9 2014/05/06 12:56:22 fclement Exp $ *)

open Refinement_types;;
open Scalar_spec;;
open Components_spec;;

module type MAKER =
  functor (Scal : SCALAR) ->
  functor (Comps : COMPONENTS) ->
sig
  type scalar = Scal.t;;
  type 'a components = 'a Comps.t;;
  
  type parameters = scalar parameter components;;
  type gradients = scalar gradient components;;
  type partitions = scalar partition components;;
  type zonations = scalar zonation components;;
  
  type cost = scalar exact_indicator;;
  
  type state = zonations * cost;;
  (** A [state] is the association of an homogeneous tuple of scalar
   zonations with the corresponding cost function, or exact indicator. *)
  
  type selected_cutting = state;;
  (** A [selected_cutting] is intended to be a candidate [state] with no first
   order indicator computed (nonempty list in the to_do field of delayed
   graphs; in practice, it will be the list of all components). *)
end
;;
