CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C                                                                     C
C                              Ref-indic                              C
C                                                                     C
C                        Refinement indicators                        C
C                                                                     C
C               EPI Pomdapi, INRIA Paris - Rocquencourt               C
C                                                                     C
C  Copyright (c) 2013-2014 INRIA.                                     C
C  Institut National de Recherche en Informatique et en Automatique.  C
C  All rights reserved. This file is distributed only by permission.  C
C                                                                     C
C  Hend Ben Ameur <hbenameur@yahoo.ca>                                C
C  Francois Clement <Francois.Clement@inria.fr>                       C
C  Pierre Weis <Pierre.Weis@inria.fr>                                 C
C                                                                     C
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC

C     $Id: worker.fpp,v 1.3 2014/06/25 14:55:52 fclement Exp $

#include "worker_constants.h"

      subroutine worker_main_body(init, grad, optim, final)
C     Main body.
      
      implicit none
      
      include 'pio_user_error_definition.fh'
      include 'worker_init_definition.fh'
      
C     Input arguments.
      external init, grad, optim, final
      
CCC      call pio_user_set_report_mode
CCC      call pio_user_set_debug_mode
CCC      call pio_set_report_mode
CCC      call pio_set_debug_mode
      
      call pio_user_set_message_prefix(10, '[Worker]: ')
      
      call pio_user_report_message('start user model')
      
      ier = 0
      initialized = .False.
      finished = .False.
      
      call pio_user_parse_config_file
      if (ier .ne. 0) then
         call pio_user_write_and_send_error_message
         stop
      endif
      
      call worker_loop(init, grad, optim, final)
      if (ier .ne. 0) then
         call pio_user_write_and_send_error_message
         stop
      endif
      
      call pio_user_report_message('finish user model')
      
      return
      end


      subroutine worker_loop(init, grad, optim, final)
C     Infinite loop.
      
      implicit none
      
      include 'pio_user_error_definition.fh'
      include 'worker_init_definition.fh'
      
C     Input arguments.
      external init, grad, optim, final
      
C     Local variables.
      character sbr*11, task_name*PIO_MAX_IDENT_LENGTH
      integer s_len, tc, len
      
C     External functions.
      logical pio_user_get_report_mode
      integer pio_get_communication_type
      
      s_len = 11
      sbr = 'worker_loop'
      
   10 continue
      
      call pio_receive_in_communication(PIO_STDIN)
      
      tc = pio_get_communication_type()
      
      if (tc .eq. PIO_TASK) then
         
         len = PIO_MAX_IDENT_LENGTH
         call pio_get_communication_name(len, task_name)
         
         if (pio_user_get_report_mode())
     +        write(PIO_USER_REPORT, *)
     +          '[Worker]: task "', task_name(1:len), '" received'
         
         if (task_name(1:len) .eq. 'init') then
            call worker_initialization(init, optim)
            if (ier .ne. 0) return
         else if (task_name(1:len) .eq. 'grad') then
            call worker_gradient_computation(grad)
            if (ier .ne. 0) return
         else if (task_name(1:len) .eq. 'optim') then
            call worker_optimization(optim)
            if (ier .ne. 0) return
         else if (task_name(1:len) .eq. 'final') then
            call worker_finalization(final)
            if (ier .ne. 0) return
         else
            call pio_user_error_unbound_task(s_len, sbr, len, task_name)
            return
         endif
         
      else
         
         call pio_user_error_unbound_communication(s_len, sbr, tc)
         return
         
      endif
      
      if (.not. finished) goto 10
      
      return
      end


      subroutine worker_initialization(init, optim)
C     Initialization task.
      
      implicit none
      
      include 'pio_user_error_definition.fh'
      include 'worker_init_definition.fh'
      
C     Input arguments.
      external init, optim
      
C     Local variables.
      character sbr*21
      integer s_len, nargs
      integer pp1(WORKER_MAX_SIZE, WORKER_MAX_DIMENSION)
      integer lens1(WORKER_MAX_DIMENSION), i, j
      FLOAT m1(WORKER_MAX_ZONE_NUMBER), cost1
      
C     External functions.
      logical pio_user_get_debug_mode
      integer pio_get_communication_number_of_values
      integer pio_get_int
      
      s_len = 21
      sbr = 'worker_initialization'
      
      call pio_user_set_message_prefix(23, '[Worker]: Task "init": ')
      
      call pio_user_report_message('started')
      
      nargs = pio_get_communication_number_of_values()
      call pio_user_check_number_of_values(s_len, sbr, 1, nargs)
      if (ier .ne. 0) return
      
      call pio_user_report_message('one value received')
      
      dim = pio_get_int()
      if (dim .gt. WORKER_MAX_DIMENSION) then
         call worker_error_too_large_dimension(s_len, sbr, dim)
         return
      endif
      
      call pio_user_report_message('dimension extracted')
      
      call init(pp1, lens1, m1)
      if (ier .ne. 0) return
      
      size = size_x * size_y
      if (size .gt. WORKER_MAX_SIZE) then
         call worker_error_too_large_size(s_len, sbr, size)
         return
      endif
      
      if (zone_number .gt. WORKER_MAX_ZONE_NUMBER) then
         call worker_error_too_large_zone_number
     +        (s_len, sbr, zone_number)
         return
      endif
      
      if (pio_user_get_debug_mode()) then
         do j = 1, dim
            do i = 1, size
               write(PIO_USER_DEBUG, 1001) i, j, pp1(i, j)
            enddo
         enddo
      endif
      
 1001 format('i = ', i2, ', j = ', i2, ', pp1 = ', DEBUG_FLOAT_FMT)
      
      call optim(pp1, lens1, m1, cost1)
      if (ier .ne. 0) return
      
      call pio_user_report_message('result computed')
      
      call pio_init_out_communication(PIO_RESULT, 5)
      call pio_add_int_couple(size_x, size_y)
      call pio_transpose_and_add_int_matrix
     +     (WORKER_MAX_SIZE, size, WORKER_MAX_DIMENSION, dim, pp1)
      call pio_add_int_vector(dim, lens1)
      call pio_add_float_vector(zone_number, m1)
      call pio_add_float(cost1)
      call pio_send_out_communication(PIO_STDOUT)
      
      call pio_user_report_message('result sent back')
      
      call pio_user_report_message('finished')
      
      initialized = .True.
      
      return
      end


      subroutine worker_gradient_computation(grad)
C     Gradient computation task.
      
      implicit none
      
      include 'pio_user_error_definition.fh'
      include 'worker_init_definition.fh'
      
C     Input argument.
      external grad
      
C     Local variables.
      character sbr*27
      integer s_len, nargs, dim_loc, size_loc, i, j
      FLOAT p(WORKER_MAX_SIZE, WORKER_MAX_DIMENSION)
      FLOAT g(WORKER_MAX_SIZE, WORKER_MAX_DIMENSION)
      
C     External function.
      logical pio_user_get_debug_mode
      integer pio_get_communication_number_of_values
      
      s_len = 27
      sbr = 'worker_gradient_computation'
      
      call pio_user_set_message_prefix(23, '[Worker]: Task "grad": ')
      
      call pio_user_report_message('started')
      
      if (.not. initialized) then
         call pio_user_error_not_initialized(s_len, sbr)
         return
      endif
      
      nargs = pio_get_communication_number_of_values()
      call pio_user_check_number_of_values(s_len, sbr, 1, nargs)
      if (ier .ne. 0) return
      
      call pio_user_report_message('one value received')
      
      call pio_get_and_transpose_float_matrix
     +     (WORKER_MAX_SIZE, size_loc, WORKER_MAX_DIMENSION, dim_loc, p)
      
      call pio_user_report_message('fine parameter extracted')
      
      call worker_check_dimension(s_len, sbr, dim_loc)
      if (ier .ne. 0) return
      call worker_check_size(s_len, sbr, size_loc)
      if (ier .ne. 0) return
      
      call grad(p, g)
      if (ier .ne. 0) return
      
      if (pio_user_get_debug_mode()) then
         do j = 1, dim
            do i = 1, size
               write(PIO_USER_DEBUG, 1001) i, j, p(i, j), g(i, j)
            enddo
         enddo
      endif
      
 1001 format('i = ', i2, ', j = ', i2,
     +     ', p = ', DEBUG_FLOAT_FMT,
     +     ', g = ', DEBUG_FLOAT_FMT)
      
      call pio_user_report_message('result computed')
      
      call pio_init_out_communication(PIO_RESULT, 1)
      call pio_transpose_and_add_float_matrix
     +     (WORKER_MAX_SIZE, size, WORKER_MAX_DIMENSION, dim, g)
      call pio_send_out_communication(PIO_STDOUT)
      
      call pio_user_report_message('result sent back')
      
      call pio_user_report_message('finished')
      
      return
      end


      subroutine worker_optimization(optim)
C     Optimization task.
      
      implicit none
      
      include 'pio_user_error_definition.fh'
      include 'worker_init_definition.fh'
      
C     Input argument.
      external optim
      
C     Local variables.
      character sbr*19
      integer s_len, nargs, dim_loc, size_loc, zone_number_loc
      integer pp(WORKER_MAX_SIZE, WORKER_MAX_DIMENSION)
      integer lens(WORKER_MAX_DIMENSION), j, k, k1
      FLOAT m(WORKER_MAX_ZONE_NUMBER), cost
      
C     External function.
      logical pio_user_get_debug_mode
      integer pio_get_communication_number_of_values
      
      s_len = 19
      sbr = 'worker_optimization'
      
      call pio_user_set_message_prefix(24, '[Worker]: Task "optim": ')
      
      call pio_user_report_message('started')
      
      if (.not. initialized) then
         call pio_user_error_not_initialized(s_len, sbr)
         return
      endif
      
      nargs = pio_get_communication_number_of_values()
      call pio_user_check_number_of_values(s_len, sbr, 3, nargs)
      if (ier .ne. 0) return
      
      call pio_user_report_message('three values received')
      
      call pio_get_and_transpose_int_matrix
     +     (WORKER_MAX_SIZE, size_loc, WORKER_MAX_DIMENSION, dim_loc, pp)
      
      call pio_user_report_message('partition extracted')
      
      call worker_check_dimension(s_len, sbr, dim_loc)
      if (ier .ne. 0) return
      call worker_check_size(s_len, sbr, size_loc)
      if (ier .ne. 0) return
      
      dim_loc = WORKER_MAX_DIMENSION
      call pio_get_int_vector(dim_loc, lens)
      
      call pio_user_report_message('coarse parameter lengths extracted')
      
      call worker_check_dimension(s_len, sbr, dim_loc)
      if (ier .ne. 0) return
      call worker_check_partition(s_len, sbr, pp, lens)
      if (ier .ne. 0) return
      call worker_compute_zone_number(lens)
      
      zone_number_loc = WORKER_MAX_ZONE_NUMBER
      call pio_get_float_vector(zone_number_loc, m)
      
      call pio_user_report_message('initial coarse parameter extracted')
      
      call worker_check_zone_number(s_len, sbr, zone_number_loc)
      if (ier .ne. 0) return
      
      if (pio_user_get_debug_mode()) then
         write(PIO_USER_DEBUG, *) 'Before optimization'
         k = 1
         do j = 1, dim
            do k1 = 1, lens(j)
               write(PIO_USER_DEBUG, 1001) k1, j, m(k)
               k = k + 1
            enddo
         enddo
      endif
      
      call optim(pp, lens, m, cost)
      if (ier .ne. 0) return
      
      if (pio_user_get_debug_mode()) then
         write(PIO_USER_DEBUG, *) 'After optimization'
         k = 1
         do j = 1, dim
            do k1 = 1, lens(j)
               write(PIO_USER_DEBUG, 1001) k1, j, m(k)
               k = k + 1
            enddo
         enddo
         write(PIO_USER_DEBUG, 1002) cost
      endif
      
 1001 format('zn = ', i2, ', j = ', i2, ', m = ', DEBUG_FLOAT_FMT)
 1002 format('cost = ', DEBUG_FLOAT_FMT)
      
      call pio_user_report_message('result computed')
      
      call pio_init_out_communication(PIO_RESULT, 3)
      call pio_add_int_vector(dim, lens)
      call pio_add_float_vector(zone_number, m)
      call pio_add_float(cost)
      call pio_send_out_communication(PIO_STDOUT)
      
      call pio_user_report_message('result sent back ')
      
      call pio_user_report_message('finished')
      
      return
      end


      subroutine worker_finalization(final)
C     Finalization task.
      
      implicit none
      
      include 'pio_user_error_definition.fh'
      include 'worker_init_definition.fh'
      
C     Input argument.
      external final
      
C     Local variables.
      character sbr*19
      integer s_len, nargs, dim_loc, size_loc
      FLOAT p(WORKER_MAX_SIZE, WORKER_MAX_DIMENSION)
      
C     External function.
      integer pio_get_communication_number_of_values
      
      s_len = 19
      sbr = 'worker_finalization'
      
      call pio_user_set_message_prefix(24, '[Worker]: Task "final": ')
      
      call pio_user_report_message('started')
      
      if (.not. initialized) then
         call pio_user_error_not_initialized(s_len, sbr)
         return
      endif
      
      nargs = pio_get_communication_number_of_values()
      call pio_user_check_number_of_values(s_len, sbr, 1, nargs)
      if (ier .ne. 0) return
      
      call pio_user_report_message('one value received')
      
      call pio_get_and_transpose_float_matrix
     +     (WORKER_MAX_SIZE, size_loc, WORKER_MAX_DIMENSION, dim_loc, p)
      
      call pio_user_report_message('fine parameter extracted')
      
      call worker_check_dimension(s_len, sbr, dim_loc)
      if (ier .ne. 0) return
      call worker_check_size(s_len, sbr, size_loc)
      if (ier .ne. 0) return
      
      call final(p)
      if (ier .ne. 0) return
      
      call pio_user_report_message('result computed')
      
      call pio_init_out_communication(PIO_RESULT, 1)
      call pio_add_string(8, 'OK, bye!')
      call pio_send_out_communication(PIO_STDOUT)
      
      call pio_user_report_message('result sent back')
      
      call pio_user_report_message('finished')
      
      finished = .True.
      
      return
      end


      subroutine worker_compute_zone_number(lens)
C     Compute zone number.
      
      implicit none
      
      include 'pio_user_error_definition.fh'
      include 'worker_init_definition.fh'
      
C     Input argument.
      integer lens(WORKER_MAX_DIMENSION)
      
C     Local variable.
      integer i
      
      zone_number = 0
      do i = 1, dim
         zone_number = zone_number + lens(i)
      enddo
      
      return
      end


      subroutine worker_check_partition(s_len, sbr, pp, lens)
C     Check partition.
      
      implicit none
      
      include 'pio_user_error_definition.fh'
      include 'worker_init_definition.fh'
      
C     Input arguments.
      character sbr*(*)
      integer s_len
      integer pp(WORKER_MAX_SIZE, WORKER_MAX_DIMENSION)
      integer lens(WORKER_MAX_DIMENSION)
      
C     Local variables
      integer i, j, len_j, pp_ij
      
      do j = 1, dim
         len_j = lens(j)
         do i = 1, size
            pp_ij = pp(i, j)
            if (pp_ij .lt. 0) then
               call worker_error_too_small_zone_number
     +              (s_len, sbr, pp_ij)
               return
            endif
            if (pp_ij .ge. len_j) then
               call worker_error_too_large_zone_number
     +              (s_len, sbr, pp_ij)
               return
            endif
         enddo
      enddo
      
      return
      end


      subroutine worker_check_dimension(s_len, sbr, dim_loc)
C     Check dimension.
      
      implicit none
      
      include 'pio_user_error_definition.fh'
      include 'worker_init_definition.fh'
      
C     Input arguments.
      character sbr*(*)
      integer s_len, dim_loc
      
      if (dim_loc .ne. dim) then
         call worker_error_wrong_dimension(s_len, sbr, dim, dim_loc)
      endif
      
      return
      end


      subroutine worker_check_size(s_len, sbr, size_loc)
C     Check size.
      
      implicit none
      
      include 'pio_user_error_definition.fh'
      include 'worker_init_definition.fh'
      
C     Input arguments.
      character sbr*(*)
      integer s_len, size_loc
      
      if (size_loc .ne. size) then
         call worker_error_wrong_size(s_len, sbr, size, size_loc)
      endif
      
      return
      end


      subroutine worker_check_zone_number(s_len, sbr, zone_number_loc)
C     Check zone number.
      
      implicit none
      
      include 'pio_user_error_definition.fh'
      include 'worker_init_definition.fh'
      
C     Input arguments.
      character sbr*(*)
      integer s_len, zone_number_loc
      
      if (zone_number_loc .ne. zone_number) then
         call worker_error_wrong_zone_number
     +        (s_len, sbr, zone_number, zone_number_loc)
      endif
      
      return
      end


      subroutine worker_trivial_init(value, pp1, lens1, m1)      
C     Initialize coarse parameter with only one zone in each dimension.
      
      implicit none
      
      include 'worker_init_definition.fh'
      
C     Input argument.
      FLOAT value
      
C     Output arguments.
      integer pp1(WORKER_MAX_SIZE, WORKER_MAX_DIMENSION)
      integer lens1(WORKER_MAX_DIMENSION)
      FLOAT m1(WORKER_MAX_ZONE_NUMBER)
      
C     Local variables.
      integer i, j
      
      zone_number = dim
      
      do j = 1, dim
         do i = 1, size_x * size_y
            pp1(i, j) = 0
         enddo
         lens1(j) = 1
         m1(j) = value
      enddo
      
      return
      end
